#distributing

1. set ```TWINE_USERNAME``` and ```TWINE_PASSWORD```
2. do ```./release.sh```

# testing
1. run unit tests 
    
    python -m unittest feed

2. run unit tests in pdb

    python -m pdb <test_file_path> <ClassName>.<test_method>

